@@ -99,10 +99,26 @@ def main():
     
     
     #Load Stylesheet for buttons
-    file = open(data.app_path+"UIStyle.css", 'r')
-    data.UIStyle=""
-    for line in file: data.UIStyle=data.UIStyle+line+"\n"
-    file.close()
+    try:
+        print "Load user defined style sheet"
+        file = open(data.configfolder+"UIStyle.css", 'r')
+        data.UIStyle=""
+        for line in file: data.UIStyle=data.UIStyle+line+"\n"
+        file.close()
+    except:
+        print "User defined style sheet not existing or not readable, load default one"
+        file = open(data.app_path+"UIStyle.css", 'r')
+        data.UIStyle=""
+        for line in file: data.UIStyle=data.UIStyle+line+"\n"
+        file.close()
+        try:
+            print "Create user defined style sheet in",  data.configfolder
+            file= open(data.configfolder+"UIStyle.css", 'w')
+            file.write(data.UIStyle)
+            file.close()
+        except:
+            print "Could not create user defined style sheet"
+        
     
     
     
@@ -192,7 +208,13 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #but keep alarm active!
     
-    RecordWindow.UpdateScreen()      
+    
+    if(data.DisplayIsOn==False):
+        if(data.debug==1): print "-> x Do not update screen, Display is off!"
+        pass
+    else:
+        if(data.debug==1): print "-> o Update screen"
+        RecordWindow.UpdateScreen()      
   
 #    print data.AlarmIsActive,  data.StopAfterAlarm
     if(data.AlarmIsActive==True):
@@ -253,7 +275,7 @@ def InitMeasurement():
     WriteIntoRecordFile()
    
     GenerateGraphBitmap(RecordWindow)
-    RecordWindow.UpdateScreen()
+#    RecordWindow.UpdateScreen()
     
     RecordWindow.ui.CanvasWidget.show()
     RecordWindow.UpdateScreen()
@@ -313,6 +335,8 @@ def StopMeasurement():
     global app
     
     RecordWindow.UpdateScreenStop()
+    RecordWindow.Canvas.update()
+    RecordWindow.UpdateScreen()
     
 #    DeleteAlarm() #delete Alarm if existing
     
@@ -638,11 +662,11 @@ class frmRecordWindow(QMainWindow):
         
         
     def UpdateScreen(self):    
-        if(data.DisplayIsOn==False):
-            if(data.debug==1): print "-> x Do not update screen, Display is off!"
-            return
-        else:
-            if(data.debug==1): print "-> o Update screen"
+#        if(data.DisplayIsOn==False):
+#            if(data.debug==1): print "-> x Do not update screen, Display is off!"
+#            return
+#        else:
+#            if(data.debug==1): print "-> o Update screen"
         
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
